@@ -1,14 +1,10 @@
 /*
- * $Id$
- *
  * Main Citadel header file
  *
- * Copyright (c) 1987-2010 by the citadel.org team
+ * Copyright (c) 1987-2012 by the citadel.org team
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -53,10 +49,10 @@ extern "C" {
  * usually more strict because you're not really supposed to dump/load and
  * upgrade at the same time.
  */
-#define REV_LEVEL	786		/* This version */
+#define REV_LEVEL	804		/* This version */
 #define REV_MIN		591		/* Oldest compatible database */
 #define EXPORT_REV_MIN	760		/* Oldest compatible export files */
-#define LIBCITADEL_MIN	786		/* Minimum required version of libcitadel */
+#define LIBCITADEL_MIN	804		/* Minimum required version of libcitadel */
 
 #define SERVER_TYPE 0			/* zero for stock Citadel; other developers please
 					   obtain SERVER_TYPE codes for your implementations */
@@ -153,8 +149,6 @@ struct ctdluser {			/* User record                      */
 	time_t lastcall;		/* Date/time of most recent login    */
 	int USuserpurge;		/* Purge time (in days) for user     */
 	char fullname[64];		/* Display name (primary identifier) */
-	cit_uint8_t USscreenwidth;	/* Screen width (for textmode users) */
-	cit_uint8_t USscreenheight;	/* Screen height(for textmode users) */
 };
 
 
@@ -283,7 +277,7 @@ enum {
 #define SIEVECONFIG	"application/x-citadel-sieve-config"
 #define XMPPMORTUARY	"application/x-citadel-xmpp-mortuary"
 
-#define TRACE	CtdlLogPrintf(CTDL_DEBUG, "Checkpoint: %s, %d\n", __FILE__, __LINE__)
+#define TRACE	syslog(LOG_DEBUG, "Checkpoint: %s, %d\n", __FILE__, __LINE__)
 
 #ifndef LONG_MAX
 #define LONG_MAX 2147483647L
