@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  * Header file for TCP client socket library
  *
  * Copyright (c) 1987-2009 by the citadel.org team
@@ -20,15 +18,14 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-int sock_connect(char *host, char *service, char *protocol);
-int sock_read_to(int *sock, char *buf, int bytes, int timeout, int keep_reading_until_full);
-int sock_read(int *sock, char *buf, int bytes, int keep_reading_until_full);
+int sock_connect(char *host, char *service);
 int sock_write(int *sock, const char *buf, int nbytes);
 int sock_write_timeout(int *sock, const char *buf, int nbytes, int timeout);
 int ml_sock_gets(int *sock, char *buf, int nSec);
 int sock_getln(int *sock, char *buf, int bufsize);
 int CtdlSockGetLine(int *sock, StrBuf *Target, int nSec);
 int sock_puts(int *sock, char *buf);
+int socket_read_blob(int *Socket, StrBuf * Target, int bytes, int timeout);
 
 
 /* 
