@@ -77,8 +77,8 @@ void lock_control(void)
 {
 #if defined(LOCK_EX) && defined(LOCK_NB)
 	if (flock(fileno(control_fp), (LOCK_EX | LOCK_NB))) {
-		CtdlLogPrintf(CTDL_EMERG, "citserver: unable to lock %s.\n", file_citadel_control);
-		CtdlLogPrintf(CTDL_EMERG, "Is another citserver already running?\n");
+		syslog(LOG_EMERG, "citserver: unable to lock %s.\n", file_citadel_control);
+		syslog(LOG_EMERG, "Is another citserver already running?\n");
 		exit(CTDLEXIT_CONTROL);
 	}
 #endif
@@ -127,9 +127,9 @@ void control_find_highest(struct ctdlroom *qrbuf, void *data)
 	}
 	cdb_free(cdbfr);
 	if (room_fixed)
-		CtdlLogPrintf(CTDL_INFO, "Control record checking....Fixed room counter\n");
+		syslog(LOG_INFO, "Control record checking....Fixed room counter\n");
 	if (message_fixed)
-		CtdlLogPrintf(CTDL_INFO, "Control record checking....Fixed message count\n");
+		syslog(LOG_INFO, "Control record checking....Fixed message count\n");
 	return;
 }
 
@@ -148,7 +148,7 @@ void control_find_user (struct ctdluser *EachUser, void *out_data)
 		user_fixed = 1;
 	}
 	if(user_fixed)
-		CtdlLogPrintf(CTDL_INFO, "Control record checking....Fixed user count\n");
+		syslog(LOG_INFO, "Control record checking....Fixed user count\n");
 }
 
 
@@ -176,30 +176,52 @@ void get_control(void)
 		if (control_fp != NULL) {
 			lock_control();
 			rv = fchown(fileno(control_fp), config.c_ctdluid, -1);
+			if (rv == -1)
+				syslog(LOG_EMERG, "Failed to adjust ownership of: %s [%s]\n", 
+				       file_citadel_control, strerror(errno));
 			rv = fchmod(fileno(control_fp), S_IRUSR|S_IWUSR);
+			if (rv == -1)
+				syslog(LOG_EMERG, "Failed to adjust accessrights of: %s [%s]\n", 
+				       file_citadel_control, strerror(errno));
 		}
 	}
 	if (control_fp == NULL) {
 		control_fp = fopen(file_citadel_control, "wb+");
 		if (control_fp != NULL) {
 			lock_control();
-			rv = fchown(fileno(control_fp), config.c_ctdluid, -1);
-			rv = fchmod(fileno(control_fp), S_IRUSR|S_IWUSR);
 			memset(&CitControl, 0, sizeof(struct CitControl));
+
+			rv = fchown(fileno(control_fp), config.c_ctdluid, -1);
+			if (rv == -1)
+				syslog(LOG_EMERG, "Failed to adjust ownership of: %s [%s]\n", 
+				       file_citadel_control, strerror(errno));
+
+			rv = fchmod(fileno(control_fp), S_IRUSR|S_IWUSR);
+			if (rv == -1)
+				syslog(LOG_EMERG, "Failed to adjust accessrights of: %s [%s]\n", 
+				       file_citadel_control, strerror(errno));
 			rv = fwrite(&CitControl, sizeof(struct CitControl), 1, control_fp);
+			if (rv == -1)
+				syslog(LOG_EMERG, "Failed to write: %s [%s]\n", 
+				       file_citadel_control, strerror(errno));
 			rewind(control_fp);
 		}
 	}
 	if (control_fp == NULL) {
-		CtdlLogPrintf(CTDL_ALERT, "ERROR opening %s: %s\n", file_citadel_control, strerror(errno));
+		syslog(LOG_ALERT, "ERROR opening %s: %s\n", file_citadel_control, strerror(errno));
 		return;
 	}
 
 	rewind(control_fp);
 	rv = fread(&CitControl, sizeof(struct CitControl), 1, control_fp);
+	if (rv == -1)
+		syslog(LOG_EMERG, "Failed to read Controlfile: %s [%s]\n", 
+		       file_citadel_control, strerror(errno));
 	already_have_control = 1;
 	rv = chown(file_citadel_control, config.c_ctdluid, (-1));
-	
+	if (rv == -1)
+		syslog(LOG_EMERG, "Failed to adjust ownership of: %s [%s]\n", 
+		       file_citadel_control, strerror(errno));	
 }
 
 /*
@@ -212,6 +234,9 @@ void put_control(void)
 	if (control_fp != NULL) {
 		rewind(control_fp);
 		rv = fwrite(&CitControl, sizeof(struct CitControl), 1, control_fp);
+		if (rv == -1)
+			syslog(LOG_EMERG, "Failed to write: %s [%s]\n", 
+			       file_citadel_control, strerror(errno));
 		fflush(control_fp);
 	}
 }
@@ -222,7 +247,7 @@ void put_control(void)
  */
 void check_control(void)
 {
-	CtdlLogPrintf(CTDL_INFO, "Checking/re-building control record\n");
+	syslog(LOG_INFO, "Checking/re-building control record\n");
 	get_control();
 	// Find highest room number and message number.
 	CtdlForEachRoom(control_find_highest, NULL);
@@ -308,6 +333,10 @@ long get_new_room_number(void)
 
 /* 
  * Get or set global configuration options
+ *
+ * IF YOU ADD OR CHANGE FIELDS HERE, YOU *MUST* DOCUMENT YOUR CHANGES AT:
+ * http://www.citadel.org/doku.php/documentation:appproto:system_config
+ *
  */
 void cmd_conf(char *argbuf)
 {
@@ -397,6 +426,7 @@ void cmd_conf(char *argbuf)
 		cprintf("%ld\n", config.c_pop3_fetch);
 		cprintf("%ld\n", config.c_pop3_fastest);
 		cprintf("%d\n", config.c_spam_flag_only);
+		cprintf("%d\n", config.c_guest_logins);
 		cprintf("000\n");
 	}
 
@@ -653,6 +683,9 @@ void cmd_conf(char *argbuf)
 			case 66:
 				config.c_spam_flag_only = atoi(buf);
 				break;
+			case 67:
+				config.c_guest_logins = atoi(buf);
+				break;
 			}
 			++a;
 		}
@@ -678,9 +711,12 @@ void cmd_conf(char *argbuf)
 		extract_token(confname, argbuf, 1, '|', sizeof confname);
 		confptr = CtdlGetSysConfig(confname);
 		if (confptr != NULL) {
+			long len; 
+
+			len = strlen(confptr);
 			cprintf("%d %s\n", LISTING_FOLLOWS, confname);
-			client_write(confptr, strlen(confptr));
-			if (confptr[strlen(confptr) - 1] != 10)
+			client_write(confptr, len);
+			if ((len > 0) && (confptr[len - 1] != 10))
 				client_write("\n", 1);
 			cprintf("000\n");
 			free(confptr);
@@ -716,6 +752,6 @@ CTDL_MODULE_INIT(control)
 	if (!threading) {
 		CtdlRegisterProtoHook(cmd_conf, "CONF", "get/set system configuration");
 	}
-	/* return our Subversion id for the Log */
-	return "$Id$";
+	/* return our id for the Log */
+	return "control";
 }
