@@ -12,6 +12,7 @@
 #include <ctype.h>
 #include <string.h>
 #include <sys/stat.h>
+#include <sys/mman.h>
 
 #if TIME_WITH_SYS_TIME
 # include <sys/time.h>
@@ -47,9 +48,9 @@
 /*
  * network_talking_to()  --  concurrency checker
  */
+static char *nttlist = NULL;
 int network_talking_to(char *nodename, int operation) {
 
-	static char *nttlist = NULL;
 	char *ptr = NULL;
 	int i;
 	char buf[SIZ];
@@ -96,11 +97,19 @@ int network_talking_to(char *nodename, int operation) {
 			break;
 	}
 
-	if (nttlist != NULL) CtdlLogPrintf(CTDL_DEBUG, "nttlist=<%s>\n", nttlist);
+	if (nttlist != NULL) syslog(LOG_DEBUG, "nttlist=<%s>\n", nttlist);
 	end_critical_section(S_NTTLIST);
 	return(retval);
 }
 
+void cleanup_nttlist(void)
+{
+        begin_critical_section(S_NTTLIST);
+	if (nttlist != NULL)
+		free(nttlist);
+	nttlist = NULL;
+        end_critical_section(S_NTTLIST);
+}
 
 
 
@@ -233,6 +242,7 @@ void OpenCmdResult(char *filename, const char *mime_type)
 	long filesize;
 
 	fstat(fileno(CC->download_fp), &statbuf);
+	CC->download_fp_total = statbuf.st_size;
 	filesize = (long) statbuf.st_size;
 	modtime = (time_t) statbuf.st_mtime;
 
@@ -363,6 +373,12 @@ void cmd_oimg(char *cmdbuf)
 		return;
 	}
 	rv = fread(&MimeTestBuf[0], 1, 32, CC->download_fp);
+	if (rv == -1) {
+		cprintf("%d Cannot access %s: %s\n",
+			ERROR + FILE_NOT_FOUND, pathname, strerror(errno));
+		return;
+	}
+
 	rewind (CC->download_fp);
 	OpenCmdResult(pathname, GuessMimeType(&MimeTestBuf[0], 32));
 }
@@ -591,7 +607,7 @@ void cmd_ucls(char *cmd)
 				unlink(CC->upl_path);
 			}
 			else {
-				CtdlLogPrintf(CTDL_ALERT, "Cannot link %s to %s: %s\n",
+				syslog(LOG_ALERT, "Cannot link %s to %s: %s\n",
 					CC->upl_path, final_filename, strerror(errno)
 				);
 			}
@@ -631,7 +647,6 @@ void cmd_ucls(char *cmd)
 }
 
 
-
 /*
  * read from the download file
  */
@@ -697,6 +712,10 @@ void cmd_writ(char *cmdbuf)
 	buf = malloc(bytes + 1);
 	client_read(buf, bytes);
 	rv = fwrite(buf, bytes, 1, CC->upload_fp);
+	if (rv == -1) {
+		syslog(LOG_EMERG, "Couldn't write: %s\n",
+		       strerror(errno));
+	}
 	free(buf);
 }
 
@@ -750,6 +769,7 @@ void cmd_ndop(char *cmdbuf)
 	CC->dl_is_net = 1;
 
 	stat(pathname, &statbuf);
+	CC->download_fp_total = statbuf.st_size;
 	cprintf("%d %ld\n", CIT_OK, (long)statbuf.st_size);
 }
 
@@ -819,7 +839,8 @@ CTDL_MODULE_INIT(file_ops)
 		CtdlRegisterProtoHook(cmd_nuop, "NUOP", "Open a network spool file for upload");
 		CtdlRegisterProtoHook(cmd_oimg, "OIMG", "Open an image file for download");
 		CtdlRegisterProtoHook(cmd_uimg, "UIMG", "Upload an image file");
+		CtdlRegisterCleanupHook(cleanup_nttlist);
 	}
         /* return our Subversion id for the Log */
-	return "$Id$";
+	return "file_ops";
 }
