@@ -11,5 +11,3 @@ LONG(usernum);			/* User number (never recycled)     */
 TIME(lastcall);		/* Last time the user called        */
 INTEGER(USuserpurge);		/* Purge time (in days) for user    */
 STRING_BUF(fullname,64);		/* Name for Citadel messages & mail */
-UINT8(USscreenwidth);	/* Screen width (for textmode users)*/
-UINT8(USscreenheight);	/* Screen height(for textmode users)*/
