@@ -8,21 +8,21 @@
  * Based on bits of the previous serv_funambol
  * Contact: <matt@mcbridematt.dhs.org> / <matt@comalies>
  *
- * Copyright (c) 2008-2009
+ * Copyright (c) 2008-2010
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
- *  (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include <stdio.h>
@@ -73,7 +73,7 @@ int notify_http_server(char *remoteurl,
 
 	curl = curl_easy_init();
 	if (!curl) {
-		CtdlLogPrintf(CTDL_ALERT, "Unable to initialize libcurl.\n");
+		syslog(LOG_ALERT, "Unable to initialize libcurl.\n");
 		return 1;
 	}
 
@@ -104,7 +104,12 @@ int notify_http_server(char *remoteurl,
 #endif
 	curl_easy_setopt(curl, CURLOPT_USERAGENT, CITADEL);
 	curl_easy_setopt(curl, CURLOPT_TIMEOUT, 180);		/* die after 180 seconds */
-	if (!IsEmptyStr(config.c_ip_addr)) {
+	if (
+		(!IsEmptyStr(config.c_ip_addr))
+		&& (strcmp(config.c_ip_addr, "*"))
+		&& (strcmp(config.c_ip_addr, "::"))
+		&& (strcmp(config.c_ip_addr, "0.0.0.0"))
+	) {
 		curl_easy_setopt(curl, CURLOPT_INTERFACE, config.c_ip_addr);
 	}
 
@@ -123,7 +128,7 @@ int notify_http_server(char *remoteurl,
 			snprintf(buf, SIZ, 
 				 "Cannot load template file %s [%s]won't send notification\r\n", 
 				 file_funambol_msg, strerror(errno));
-			CtdlLogPrintf(CTDL_ERR, buf);
+			syslog(LOG_ERR, "%s", buf);
 
 			CtdlAideMessage(buf, "External notifier unable to find message template!");
 			goto free;
@@ -148,7 +153,7 @@ int notify_http_server(char *remoteurl,
 			snprintf(buf, SIZ, 
 				 "Cannot load template file %s; won't send notification\r\n", 
 				 file_funambol_msg);
-			CtdlLogPrintf(CTDL_ERR, buf);
+			syslog(LOG_ERR, "%s", buf);
 
 			CtdlAideMessage(buf, "External notifier unable to load message template!");
 			goto free;
@@ -188,7 +193,7 @@ int notify_http_server(char *remoteurl,
 	if (res) {
 		StrBuf *ErrMsg;
 
-		CtdlLogPrintf(CTDL_ALERT, "libcurl error %d: %s\n", res, errmsg);
+		syslog(LOG_ALERT, "libcurl error %d: %s\n", res, errmsg);
 		ErrMsg = NewStrBufPlain(HKEY("Error sending your Notification\n"));
 		StrBufAppendPrintf(ErrMsg, "\nlibcurl error %d: %s\n", res, errmsg);
 		StrBufAppendBufPlain(ErrMsg, curl_errbuf, -1, 0);
@@ -208,7 +213,7 @@ int notify_http_server(char *remoteurl,
 		ExtNotify_PutErrorMessage(Ctx, ErrMsg);
 	}
 
-	CtdlLogPrintf(CTDL_DEBUG, "Funambol notified\n");
+	syslog(LOG_DEBUG, "Funambol notified\n");
 free:
 	curl_slist_free_all (headers);
 	curl_easy_cleanup(curl);
