@@ -1,9 +1,9 @@
 /*
  * This module dumps and/or loads the Citadel database in XML format.
  *
- * Copyright (c) 1987-2011 by the citadel.org team
+ * Copyright (c) 1987-2010 by the citadel.org team
  *
- * This program is open source software; you can redistribute it and/or modify
+ * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
@@ -191,9 +191,9 @@ void migr_export_rooms(void) {
 	 * exporting the message multiple times.)
 	 */
 	snprintf(cmd, sizeof cmd, "sort -n <%s >%s", migr_tempfilename1, migr_tempfilename2);
-	if (system(cmd) != 0) CtdlLogPrintf(CTDL_ALERT, "Error %d\n", errno);
+	if (system(cmd) != 0) syslog(LOG_ALERT, "Error %d\n", errno);
 	snprintf(cmd, sizeof cmd, "uniq <%s >%s", migr_tempfilename2, migr_tempfilename1);
-	if (system(cmd) != 0) CtdlLogPrintf(CTDL_ALERT, "Error %d\n", errno);
+	if (system(cmd) != 0) syslog(LOG_ALERT, "Error %d\n", errno);
 }
 
 
@@ -372,8 +372,8 @@ void migr_export_messages(void) {
 	Ctx = CC;
 	migr_global_message_list = fopen(migr_tempfilename1, "r");
 	if (migr_global_message_list != NULL) {
-		CtdlLogPrintf(CTDL_INFO, "Opened %s\n", migr_tempfilename1);
-		while ((Ctx->kill_me != 1) && 
+		syslog(LOG_INFO, "Opened %s\n", migr_tempfilename1);
+		while ((Ctx->kill_me == 0) && 
 		       (fgets(buf, sizeof(buf), migr_global_message_list) != NULL)) {
 			msgnum = atol(buf);
 			if (msgnum > 0L) {
@@ -383,10 +383,10 @@ void migr_export_messages(void) {
 		}
 		fclose(migr_global_message_list);
 	}
-	if (Ctx->kill_me != 1)
-		CtdlLogPrintf(CTDL_INFO, "Exported %d messages.\n", count);
+	if (Ctx->kill_me == 0)
+		syslog(LOG_INFO, "Exported %d messages.\n", count);
 	else
-		CtdlLogPrintf(CTDL_ERR, "Export aborted due to client disconnect! \n");
+		syslog(LOG_ERR, "Export aborted due to client disconnect! \n");
 
 	migr_export_message(-1L);	/* This frees the encoding buffer */
 }
@@ -394,8 +394,6 @@ void migr_export_messages(void) {
 
 
 void migr_do_export(void) {
-	struct config *buf;
-	buf = &config;
 	CitContext *Ctx;
 
 	Ctx = CC;
@@ -494,12 +492,12 @@ void migr_do_export(void) {
 	cprintf("<control_version>%d</control_version>\n", CitControl.version);
 	client_write("</control>\n", 11);
 
-	if (Ctx->kill_me != 1)	migr_export_users();
-	if (Ctx->kill_me != 1)	migr_export_openids();
-	if (Ctx->kill_me != 1)	migr_export_rooms();
-	if (Ctx->kill_me != 1)	migr_export_floors();
-	if (Ctx->kill_me != 1)	migr_export_visits();
-	if (Ctx->kill_me != 1)	migr_export_messages();
+	if (Ctx->kill_me == 0)	migr_export_users();
+	if (Ctx->kill_me == 0)	migr_export_openids();
+	if (Ctx->kill_me == 0)	migr_export_rooms();
+	if (Ctx->kill_me == 0)	migr_export_floors();
+	if (Ctx->kill_me == 0)	migr_export_visits();
+	if (Ctx->kill_me == 0)	migr_export_messages();
 	client_write("</citadel_migrate_data>\n", 24);
 	client_write("000\n", 4);
 	Ctx->dont_term = 0;
@@ -579,7 +577,7 @@ void migr_xml_start(void *data, const char *el, const char **attr) {
 	}
 
 	if (citadel_migrate_data != 1) {
-		CtdlLogPrintf(CTDL_ALERT, "Out-of-sequence tag <%s> detected.  Warning: ODD-DATA!\n", el);
+		syslog(LOG_ALERT, "Out-of-sequence tag <%s> detected.  Warning: ODD-DATA!\n", el);
 		return;
 	}
 
@@ -624,7 +622,7 @@ void migr_xml_end(void *data, const char *el) {
 	}
 
 	if (citadel_migrate_data != 1) {
-		CtdlLogPrintf(CTDL_ALERT, "Out-of-sequence tag <%s> detected.  Warning: ODD-DATA!\n", el);
+		syslog(LOG_ALERT, "Out-of-sequence tag <%s> detected.  Warning: ODD-DATA!\n", el);
 		return;
 	}
 
@@ -633,14 +631,14 @@ void migr_xml_end(void *data, const char *el) {
 		migr_chardata_len = 0;
 	}
 
-	// CtdlLogPrintf(CTDL_DEBUG, "END TAG: <%s> DATA: <%s>\n", el, (migr_chardata_len ? migr_chardata : ""));
+	// syslog(LOG_DEBUG, "END TAG: <%s> DATA: <%s>\n", el, (migr_chardata_len ? migr_chardata : ""));
 
 	/*** CONFIG ***/
 
 	if (!strcasecmp(el, "config")) {
 		config.c_enable_fulltext = 0;	/* always disable */
 		put_config();
-		CtdlLogPrintf(CTDL_INFO, "Completed import of server configuration\n");
+		syslog(LOG_INFO, "Completed import of server configuration\n");
 	}
 
 	else if (!strcasecmp(el, "c_nodename"))			safestrncpy(config.c_nodename, migr_chardata, sizeof config.c_nodename);
@@ -729,7 +727,7 @@ void migr_xml_end(void *data, const char *el) {
 	else if (!strcasecmp(el, "control")) {
 		CitControl.MMfulltext = (-1L);	/* always flush */
 		put_control();
-		CtdlLogPrintf(CTDL_INFO, "Completed import of control record\n");
+		syslog(LOG_INFO, "Completed import of control record\n");
 	}
 
 	/*** USER ***/
@@ -748,7 +746,7 @@ void migr_xml_end(void *data, const char *el) {
 
 	else if (!strcasecmp(el, "user")) {
 		CtdlPutUser(&usbuf);
-		CtdlLogPrintf(CTDL_INFO, "Imported user: %s\n", usbuf.fullname);
+		syslog(LOG_INFO, "Imported user: %s\n", usbuf.fullname);
 	}
 
 	/*** OPENID ***/
@@ -765,7 +763,7 @@ void migr_xml_end(void *data, const char *el) {
 		memcpy(&oid_data[sizeof(long)], openid_url, strlen(openid_url) + 1);
 		cdb_store(CDB_OPENID, openid_url, strlen(openid_url), oid_data, oid_data_len);
 		free(oid_data);
-		CtdlLogPrintf(CTDL_INFO, "Imported OpenID: %s (%ld)\n", openid_url, openid_usernum);
+		syslog(LOG_INFO, "Imported OpenID: %s (%ld)\n", openid_url, openid_usernum);
 	}
 
 	/*** ROOM ***/
@@ -789,7 +787,7 @@ void migr_xml_end(void *data, const char *el) {
 
 	else if (!strcasecmp(el, "room")) {
 		CtdlPutRoom(&qrbuf);
-		CtdlLogPrintf(CTDL_INFO, "Imported room: %s\n", qrbuf.QRname);
+		syslog(LOG_INFO, "Imported room: %s\n", qrbuf.QRname);
 	}
 
 	/*** ROOM MESSAGE POINTERS ***/
@@ -802,7 +800,7 @@ void migr_xml_end(void *data, const char *el) {
 			msglist_alloc = 1000;
 			msglist = malloc(sizeof(long) * msglist_alloc);
 
-			CtdlLogPrintf(CTDL_DEBUG, "Message list for: %s\n", FRname);
+			syslog(LOG_DEBUG, "Message list for: %s\n", FRname);
 
 			ptr = migr_chardata;
 			while (*ptr != 0) {
@@ -830,8 +828,8 @@ void migr_xml_end(void *data, const char *el) {
 			free(msglist);
 			msglist = NULL;
 			msglist_alloc = 0;
-			CtdlLogPrintf(CTDL_DEBUG, "Imported %d messages.\n", msgcount);
-			if (CtdlThreadCheckStop()) {
+			syslog(LOG_DEBUG, "Imported %d messages.\n", msgcount);
+			if (server_shutting_down) {
 				return;
 		}
 	}
@@ -847,7 +845,7 @@ void migr_xml_end(void *data, const char *el) {
 
 	else if (!strcasecmp(el, "floor")) {
 		CtdlPutFloor(&flbuf, floornum);
-		CtdlLogPrintf(CTDL_INFO, "Imported floor #%d (%s)\n", floornum, flbuf.f_name);
+		syslog(LOG_INFO, "Imported floor #%d (%s)\n", floornum, flbuf.f_name);
 	}
 
 	/*** VISITS ***/
@@ -869,7 +867,7 @@ void migr_xml_end(void *data, const char *el) {
 
 	else if (!strcasecmp(el, "visit")) {
 		put_visit(&vbuf);
-		CtdlLogPrintf(CTDL_INFO, "Imported visit: %ld/%ld/%ld\n", vbuf.v_roomnum, vbuf.v_roomgen, vbuf.v_usernum);
+		syslog(LOG_INFO, "Imported visit: %ld/%ld/%ld\n", vbuf.v_roomnum, vbuf.v_roomgen, vbuf.v_usernum);
 	}
 
 	/*** MESSAGES ***/
@@ -889,7 +887,7 @@ void migr_xml_end(void *data, const char *el) {
 		free(decoded_msg);
 		decoded_msg = NULL;
 		PutMetaData(&smi);
-		CtdlLogPrintf(CTDL_INFO, "Imported message #%ld, size=%ld, refcount=%d, content-type: %s\n",
+		syslog(LOG_INFO, "Imported message #%ld, size=%ld, refcount=%d, content-type: %s\n",
 			import_msgnum, msglen, smi.meta_refcount, smi.meta_content_type);
 	}
 
@@ -932,7 +930,7 @@ void migr_do_import(void) {
 		linelen = strlen(buf);
 		strcpy(&buf[linelen++], "\n");
 
-		if (CtdlThreadCheckStop())
+		if (server_shutting_down)
 			break;	// Should we break or return?
 		
 		if (buf[0] == '\0')
@@ -1017,6 +1015,6 @@ CTDL_MODULE_INIT(migrate)
 		CtdlRegisterProtoHook(cmd_migr, "ARTV", "Across-the-wire migration (legacy syntax)");
 	}
 	
-	/* return our Subversion id for the Log */
-	return "$Id$";
+	/* return our module name for the log */
+	return "migrate";
 }
