@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  * This module handles instant messaging between users.
  * 
  * Copyright (c) 2010 by the citadel.org team
@@ -273,6 +271,6 @@ CTDL_MODULE_INIT(roomchat)
 		CtdlRegisterSessionHook(roomchat_shutdown, EVT_SHUTDOWN);
 	}
 	
-	/* return our Subversion id for the Log */
-	return "$Id$";
+	/* return our module name for the log */
+	return "roomchat";
 }
