@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  * This module implements server commands related to the display and
  * manipulation of the "Who's online" list.
  *
@@ -292,6 +290,6 @@ CTDL_MODULE_INIT(rwho)
 	        CtdlRegisterProtoHook(cmd_stel, "STEL", "Enter/exit stealth mode");
 	}
 	
-	/* return our Subversion id for the Log */
-        return "$Id$";
+	/* return our module name for the log */
+        return "rwho";
 }
