@@ -1,11 +1,9 @@
 /*
- * $Id$ 
- *
  * Handle XMPP presence exchanges
  *
  * Copyright (c) 2007-2010 by Art Cancro
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is open source software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
@@ -121,7 +119,7 @@ void xmpp_wholist_presence_dump(void)
  * Function to remove a buddy subscription and delete from the roster
  * (used in several places)
  */
-void xmpp_destroy_buddy(char *presence_jid) {
+void xmpp_destroy_buddy(char *presence_jid, int aggressively) {
 	static int unsolicited_id = 1;
 	char xmlbuf1[256];
 	char xmlbuf2[256];
@@ -135,10 +133,20 @@ void xmpp_destroy_buddy(char *presence_jid) {
 		xmlesc(xmlbuf1, presence_jid, sizeof xmlbuf1),
 		xmlesc(xmlbuf2, XMPP->client_jid, sizeof xmlbuf2)
 	);
-	cprintf("<presence type=\"unsubscribed\" from=\"%s\" to=\"%s\"></presence>",
-		xmlesc(xmlbuf1, presence_jid, sizeof xmlbuf1),
-		xmlesc(xmlbuf2, XMPP->client_jid, sizeof xmlbuf2)
-	);
+
+	/*
+	 * Setting the "aggressively" flag also sends an "unsubscribed" presence update.
+	 * We only ask for this when flushing the client side roster, because if we do it
+	 * in the middle of a session when another user logs off, some clients (Jitsi) interpret
+	 * it as a rejection of a subscription request.
+	 */
+	if (aggressively) {
+		cprintf("<presence type=\"unsubscribed\" from=\"%s\" to=\"%s\"></presence>",
+			xmlesc(xmlbuf1, presence_jid, sizeof xmlbuf1),
+			xmlesc(xmlbuf2, XMPP->client_jid, sizeof xmlbuf2)
+		);
+	}
+
 	// FIXME ... we should implement xmpp_indicate_nonpresence so we can use it elsewhere
 
 	/* Do an unsolicited roster update that deletes the contact. */
@@ -186,12 +194,12 @@ void xmpp_presence_notify(char *presence_jid, int event_type) {
 		}
 	}
 
-	CtdlLogPrintf(CTDL_DEBUG, "%d sessions for <%s> are now visible to session %d\n",
+	syslog(LOG_DEBUG, "%d sessions for <%s> are now visible to session %d\n",
 		visible_sessions, presence_jid, CC->cs_pid);
 
 	if ( (event_type == XMPP_EVT_LOGIN) && (visible_sessions == 1) ) {
 
-		CtdlLogPrintf(CTDL_DEBUG, "Telling session %d that <%s> logged in\n",
+		syslog(LOG_DEBUG, "Telling session %d that <%s> logged in\n",
 			CC->cs_pid, presence_jid);
 
 		/* Do an unsolicited roster update that adds a new contact. */
@@ -206,9 +214,9 @@ void xmpp_presence_notify(char *presence_jid, int event_type) {
 	}
 
 	if (visible_sessions == 0) {
-		CtdlLogPrintf(CTDL_DEBUG, "Telling session %d that <%s> logged out\n",
+		syslog(LOG_DEBUG, "Telling session %d that <%s> logged out\n",
 			CC->cs_pid, presence_jid);
-		xmpp_destroy_buddy(presence_jid);
+		xmpp_destroy_buddy(presence_jid, 0);	/* non aggressive presence update */
 	}
 
 	free(cptr);
@@ -263,7 +271,7 @@ void xmpp_fetch_mortuary_backend(long msgnum, void *userdata) {
 HashList *xmpp_fetch_mortuary(void) {
 	HashList *mortuary = NewHash(1, NULL);
 	if (!mortuary) {
-		CtdlLogPrintf(CTDL_ALERT, "NewHash() failed!\n");
+		syslog(LOG_ALERT, "NewHash() failed!\n");
 		return(NULL);
 	}
 
@@ -393,7 +401,7 @@ void xmpp_delete_old_buddies_who_no_longer_exist_from_the_client_roster(void)
 		}
 
 		if (!online_now) {
-			xmpp_destroy_buddy((char *)Value);
+			xmpp_destroy_buddy((char *)Value, 1);	/* aggressive presence update */
 		}
 
 	}
