@@ -1,6 +1,4 @@
 /*
- * $Id$ 
- *
  * XMPP event queue
  *
  * Copyright (c) 2007-2009 by Art Cancro
@@ -68,7 +66,7 @@ void xmpp_queue_event(int event_type, char *email_addr) {
 	int purged_something = 0;
 	struct CitContext *cptr;
 
-	CtdlLogPrintf(CTDL_DEBUG, "xmpp_queue_event(%d, %s)\n", event_type, email_addr);
+	syslog(LOG_DEBUG, "xmpp_queue_event(%d, %s)\n", event_type, email_addr);
 
 	/* Purge events more than a minute old */
 	begin_critical_section(S_XMPP_QUEUE);
@@ -148,3 +146,19 @@ void xmpp_process_events(void) {
 
 	XMPP->last_event_processed = highest_event;
 }
+
+
+void xmpp_cleanup_events(void)
+{
+        struct xmpp_event *ptr, *ptr2;
+        begin_critical_section(S_XMPP_QUEUE);
+	ptr = xmpp_queue;
+	xmpp_queue = NULL;
+	while (ptr != NULL) {
+		ptr2 = ptr->next;
+		free(ptr);
+		ptr = ptr2;
+	}
+        end_critical_section(S_XMPP_QUEUE);
+
+}
