@@ -1,9 +1,22 @@
 /*
- * $Id$
- *
  * Citadel Dynamic Loading Module
  * Written by Brian Costello <btx@calyx.net>
  *
+ * Copyright (c) 1987-2011 by the citadel.org team
+ *
+ * This program is open source software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
 #include "sysdep.h"
@@ -15,6 +28,7 @@
 #include <string.h>
 #include <limits.h>
 #include <ctype.h>
+#include <syslog.h>
 #include <libcitadel.h>
 #include "citadel.h"
 #include "server.h"
@@ -56,126 +70,101 @@ HashList *ProtoHookList = NULL;
 #define ERR_PORT (1 << 1)
 
 
-static char *portlist = NULL;
-static size_t nSizPort = 0;
+static StrBuf *portlist = NULL;
 
-static char *errormessages = NULL;
-size_t nSizErrmsg = 0;
+static StrBuf *errormessages = NULL;
 
 
 long   DetailErrorFlags;
-
+ConstStr Empty = {HKEY("")};
 char *ErrSubject = "Startup Problems";
-char *ErrGeneral = "Citadel had trouble on starting up. %s This means, citadel won't be the service provider for a specific service you configured it to.\n\n"
-"If you don't want citadel to provide these services, turn them off in WebCit via %s%s\n\n%s\n\n"
-"To make both ways actualy take place restart the citserver with \"sendcommand down\"\n\n"
-"The errors returned by the system were:\n%s\n"
-"You can recheck the above if you follow this faq item:\n"
-"http://www.citadel.org/doku.php/faq:mastering_your_os:net#netstat";
+ConstStr ErrGeneral[] = {
+	{HKEY("Citadel had trouble on starting up. ")},
+	{HKEY(" This means, citadel won't be the service provider for a specific service you configured it to.\n\n"
+	      "If you don't want citadel to provide these services, turn them off in WebCit via: ")},
+	{HKEY("To make both ways actualy take place restart the citserver with \"sendcommand down\"\n\n"
+	      "The errors returned by the system were:\n")},
+	{HKEY("You can recheck the above if you follow this faq item:\n"
+	      "http://www.citadel.org/doku.php/faq:mastering_your_os:net#netstat")}
+};
 
-
-char *ErrPortShort = "We couldn't bind all ports you configured to be provided by citadel server.";
-char *ErrPortWhere = "Admin->System Preferences->Network.\n\nThe failed ports and sockets are: ";
-char *ErrPortHint = "If you want citadel to provide you with that functionality, "
-"check the output of \"netstat -lnp\" on linux Servers or \"netstat -na\" on *BSD"
-" and stop the programm, that binds these ports.\n You should eventually remove "
-" their initscripts in /etc/init.d so that you won't get this trouble once more.\n"
-" After that goto Administration -> Shutdown Citadel to make Citadel retry to bind this port.\n";
+ConstStr ErrPortShort = { HKEY("We couldn't bind all ports you configured to be provided by citadel server.\n")};
+ConstStr ErrPortWhere = { HKEY("\"Admin->System Preferences->Network\".\n\nThe failed ports and sockets are: ")};
+ConstStr ErrPortHint  = { HKEY("If you want citadel to provide you with that functionality, "
+			       "check the output of \"netstat -lnp\" on linux Servers or \"netstat -na\" on *BSD"
+			       " and stop the program that binds these ports.\n You should eventually remove "
+			       " their initscripts in /etc/init.d so that you won't get this trouble once more.\n"
+			       " After that goto \"Administration -> Shutdown Citadel\" to make Citadel restart & retry to bind this port.\n")};
 
 
 void LogPrintMessages(long err)
 {
-	char *List, *DetailList, *Short, *Where, *Hint, *Message; 
-	int n = nSizPort + nSizErrmsg + 5;
+	StrBuf *Message;
+	StrBuf *List, *DetailList;
+	ConstStr *Short, *Where, *Hint; 
 
-	Message = (char*) malloc(n * SIZ);
+	
+	Message = NewStrBufPlain(NULL, 
+				 StrLength(portlist) + StrLength(errormessages));
 	
 	DetailErrorFlags = DetailErrorFlags & ~err;
 
 	switch (err)
 	{
 	case ERR_PORT:
-		Short = ErrPortShort;
-		Where = ErrPortWhere;
-		Hint  = ErrPortHint;
+		Short = &ErrPortShort;
+		Where = &ErrPortWhere;
+		Hint  = &ErrPortHint;
 		List  = portlist;
 		DetailList = errormessages;
 		break;
 	default:
-		Short = "";
-		Where = "";
-		Hint  = "";
-		List  = "";
-		DetailList = "";
+		Short = &Empty;
+		Where = &Empty;
+		Hint  = &Empty;
+		List  = NULL;
+		DetailList = NULL;
 	}
 
+	StrBufAppendBufPlain(Message, CKEY(ErrGeneral[0]), 0);
+	StrBufAppendBufPlain(Message, CKEY(*Short), 0);	
+	StrBufAppendBufPlain(Message, CKEY(ErrGeneral[1]), 0);
+	StrBufAppendBufPlain(Message, CKEY(*Where), 0);
+	StrBufAppendBuf(Message, List, 0);
+	StrBufAppendBufPlain(Message, HKEY("\n\n"), 0);
+	StrBufAppendBufPlain(Message, CKEY(*Hint), 0);
+	StrBufAppendBufPlain(Message, HKEY("\n\n"), 0);
+	StrBufAppendBufPlain(Message, CKEY(ErrGeneral[2]), 0);
+	StrBufAppendBuf(Message, DetailList, 0);
+	StrBufAppendBufPlain(Message, HKEY("\n\n"), 0);
+	StrBufAppendBufPlain(Message, CKEY(ErrGeneral[3]), 0);
 
-	snprintf(Message, n * SIZ, ErrGeneral, Short, Where, List, Hint, DetailList);
+	syslog(LOG_EMERG, "%s", ChrPtr(Message));
+	syslog(LOG_EMERG, "%s", ErrSubject);
+	quickie_message("Citadel", NULL, NULL, AIDEROOM, ChrPtr(Message), FMT_FIXED, ErrSubject);
 
-	CtdlLogPrintf(0,Message);
-	CtdlLogPrintf(0,ErrSubject);
-	quickie_message("Citadel", NULL, NULL, AIDEROOM, Message, FMT_FIXED, ErrSubject);
-	if (errormessages!=NULL) free (errormessages);
-	errormessages = NULL;
-	if (portlist!=NULL) free (portlist);
-	portlist = NULL;
-	free(Message);
+	FreeStrBuf(&Message);
+	FreeStrBuf(&List);
+	FreeStrBuf(&DetailList);
 }
 
 
-
-void AppendString(char **target, char *append, size_t *len, size_t rate)
-{
-	size_t oLen = 0;
-	long AddLen;
-	long RelPtr = 0;
-
-	AddLen = strlen(append);
-
-	if (*len == 0)
-	{
-		*len = rate;
-
-		*target = (char*)malloc (*len * SIZ);
-	}
-	else 
-	{
-		oLen = strlen(*target);
-		RelPtr = strlen(*target);
-		if (oLen + AddLen + 2 > *len * SIZ)
-		{
-			char *Buff = *target;
-			size_t NewSiz = *len + 10;
-			*target = malloc (NewSiz * SIZ);
-			memcpy (*target, Buff, NewSiz * SIZ);
-			*len = NewSiz;
-		}
-	}
-	memcpy (*target + oLen, append, AddLen);
-	(*target)[oLen + AddLen + 1] = '\n';
-	(*target)[oLen + AddLen + 2] = '\0';
-}
-
 void AddPortError(char *Port, char *ErrorMessage)
 {
-	char *pos;
 	long len;
 
 	DetailErrorFlags |= ERR_PORT;
 
-	AppendString(&errormessages, ErrorMessage, &nSizErrmsg, 10);
-	AppendString(&portlist, Port, &nSizPort, 2);
+	len = StrLength(errormessages);
+	if (len > 0) StrBufAppendBufPlain(errormessages, HKEY("; "), 0);
+	else errormessages = NewStrBuf();
+	StrBufAppendBufPlain(errormessages, ErrorMessage, -1, 0);
 
-	pos = strchr (portlist, ':');
-	if (pos != NULL) *pos = ';';
-	
-	len = strlen (errormessages);
-	if (nSizErrmsg * SIZ > len + 3)
-	{
-		errormessages[len] = ';';
-		errormessages[len+1] = ' ';
-		errormessages[len+2] = '\0';
-	}	
+
+	len = StrLength(portlist);
+	if (len > 0) StrBufAppendBufPlain(portlist, HKEY(";"), 0);
+	else portlist = NewStrBuf();
+	StrBufAppendBufPlain(portlist, Port, -1, 0);
 }
 
 
@@ -192,7 +181,7 @@ int DLoader_Exec_Cmd(char *cmdbuf)
 	return 0;
 }
 
-int FourHash(const char *key, long length) 
+long FourHash(const char *key, long length) 
 {
 	int i;
 	int ret = 0;
@@ -228,7 +217,7 @@ void CtdlRegisterProtoHook(void (*handler) (char *), char *cmd, char *desc)
 	p->desc = desc;
 
 	Put(ProtoHookList, cmd, 4, p, NULL);
-	CtdlLogPrintf(CTDL_INFO, "Registered server command %s (%s)\n", cmd, desc);
+	syslog(LOG_INFO, "Registered server command %s (%s)\n", cmd, desc);
 }
 
 void CtdlDestroyProtoHooks(void)
@@ -249,7 +238,7 @@ void CtdlRegisterCleanupHook(void (*fcn_ptr) (void))
 	newfcn->h_function_pointer = fcn_ptr;
 	CleanupHookTable = newfcn;
 
-	CtdlLogPrintf(CTDL_INFO, "Registered a new cleanup function\n");
+	syslog(LOG_INFO, "Registered a new cleanup function\n");
 }
 
 
@@ -261,7 +250,7 @@ void CtdlUnregisterCleanupHook(void (*fcn_ptr) (void))
 		/* This will also remove duplicates if any */
 		while (cur != NULL &&
 				fcn_ptr == cur->h_function_pointer) {
-			CtdlLogPrintf(CTDL_INFO, "Unregistered cleanup function\n");
+			syslog(LOG_INFO, "Unregistered cleanup function\n");
 			p = cur->next;
 			if (cur == CleanupHookTable) {
 				CleanupHookTable = p;
@@ -279,7 +268,7 @@ void CtdlDestroyCleanupHooks(void)
 	cur = CleanupHookTable;
 	while (cur != NULL)
 	{
-		CtdlLogPrintf(CTDL_INFO, "Destroyed cleanup function\n");
+		syslog(LOG_INFO, "Destroyed cleanup function\n");
 		p = cur->next;
 		free(cur);
 		cur = p;
@@ -300,7 +289,7 @@ void CtdlRegisterSessionHook(void (*fcn_ptr) (void), int EventType)
 	newfcn->eventtype = EventType;
 	SessionHookTable = newfcn;
 
-	CtdlLogPrintf(CTDL_INFO, "Registered a new session function (type %d)\n",
+	syslog(LOG_INFO, "Registered a new session function (type %d)\n",
 		EventType);
 }
 
@@ -314,7 +303,7 @@ void CtdlUnregisterSessionHook(void (*fcn_ptr) (void), int EventType)
 		while (cur != NULL &&
 				fcn_ptr == cur->h_function_pointer &&
 				EventType == cur->eventtype) {
-			CtdlLogPrintf(CTDL_INFO, "Unregistered session function (type %d)\n",
+			syslog(LOG_INFO, "Unregistered session function (type %d)\n",
 					EventType);
 			p = cur->next;
 			if (cur == SessionHookTable) {
@@ -333,7 +322,7 @@ void CtdlDestroySessionHooks(void)
 	cur = SessionHookTable;
 	while (cur != NULL)
 	{
-		CtdlLogPrintf(CTDL_INFO, "Destroyed session function\n");
+		syslog(LOG_INFO, "Destroyed session function\n");
 		p = cur->next;
 		free(cur);
 		cur = p;
@@ -354,7 +343,7 @@ void CtdlRegisterUserHook(void (*fcn_ptr) (struct ctdluser *), int EventType)
 	newfcn->eventtype = EventType;
 	UserHookTable = newfcn;
 
-	CtdlLogPrintf(CTDL_INFO, "Registered a new user function (type %d)\n",
+	syslog(LOG_INFO, "Registered a new user function (type %d)\n",
 		EventType);
 }
 
@@ -368,7 +357,7 @@ void CtdlUnregisterUserHook(void (*fcn_ptr) (struct ctdluser *), int EventType)
 		while (cur != NULL &&
 				fcn_ptr == cur->h_function_pointer &&
 				EventType == cur->eventtype) {
-			CtdlLogPrintf(CTDL_INFO, "Unregistered user function (type %d)\n",
+			syslog(LOG_INFO, "Unregistered user function (type %d)\n",
 					EventType);
 			p = cur->next;
 			if (cur == UserHookTable) {
@@ -387,7 +376,7 @@ void CtdlDestroyUserHooks(void)
 	cur = UserHookTable;
 	while (cur != NULL)
 	{
-		CtdlLogPrintf(CTDL_INFO, "Destroyed user function \n");
+		syslog(LOG_INFO, "Destroyed user function \n");
 		p = cur->next;
 		free(cur);
 		cur = p;
@@ -409,7 +398,7 @@ void CtdlRegisterMessageHook(int (*handler)(struct CtdlMessage *),
 	newfcn->eventtype = EventType;
 	MessageHookTable = newfcn;
 
-	CtdlLogPrintf(CTDL_INFO, "Registered a new message function (type %d)\n",
+	syslog(LOG_INFO, "Registered a new message function (type %d)\n",
 		EventType);
 }
 
@@ -424,7 +413,7 @@ void CtdlUnregisterMessageHook(int (*handler)(struct CtdlMessage *),
 		while (cur != NULL &&
 				handler == cur->h_function_pointer &&
 				EventType == cur->eventtype) {
-			CtdlLogPrintf(CTDL_INFO, "Unregistered message function (type %d)\n",
+			syslog(LOG_INFO, "Unregistered message function (type %d)\n",
 					EventType);
 			p = cur->next;
 			if (cur == MessageHookTable) {
@@ -443,7 +432,7 @@ void CtdlDestroyMessageHook(void)
 	cur = MessageHookTable; 
 	while (cur != NULL)
 	{
-		CtdlLogPrintf(CTDL_INFO, "Destroyed message function (type %d)\n", cur->eventtype);
+		syslog(LOG_INFO, "Destroyed message function (type %d)\n", cur->eventtype);
 		p = cur->next;
 		free(cur);
 		cur = p;
@@ -462,7 +451,7 @@ void CtdlRegisterRoomHook(int (*fcn_ptr)(struct ctdlroom *))
 	newfcn->fcn_ptr = fcn_ptr;
 	RoomHookTable = newfcn;
 
-	CtdlLogPrintf(CTDL_INFO, "Registered a new room function\n");
+	syslog(LOG_INFO, "Registered a new room function\n");
 }
 
 
@@ -472,7 +461,7 @@ void CtdlUnregisterRoomHook(int (*fcn_ptr)(struct ctdlroom *))
 
 	for (cur = RoomHookTable; cur != NULL; cur = cur->next) {
 		while (cur != NULL && fcn_ptr == cur->fcn_ptr) {
-			CtdlLogPrintf(CTDL_INFO, "Unregistered room function\n");
+			syslog(LOG_INFO, "Unregistered room function\n");
 			p = cur->next;
 			if (cur == RoomHookTable) {
 				RoomHookTable = p;
@@ -491,7 +480,7 @@ void CtdlDestroyRoomHooks(void)
 	cur = RoomHookTable;
 	while (cur != NULL)
 	{
-		CtdlLogPrintf(CTDL_INFO, "Destroyed room function\n");
+		syslog(LOG_INFO, "Destroyed room function\n");
 		p = cur->next;
 		free(cur);
 		cur = p;
@@ -509,7 +498,7 @@ void CtdlRegisterNetprocHook(int (*handler)(struct CtdlMessage *, char *) )
 	newfcn->h_function_pointer = handler;
 	NetprocHookTable = newfcn;
 
-	CtdlLogPrintf(CTDL_INFO, "Registered a new netproc function\n");
+	syslog(LOG_INFO, "Registered a new netproc function\n");
 }
 
 
@@ -521,7 +510,7 @@ void CtdlUnregisterNetprocHook(int (*handler)(struct CtdlMessage *, char *) )
 		/* This will also remove duplicates if any */
 		while (cur != NULL &&
 				handler == cur->h_function_pointer ) {
-			CtdlLogPrintf(CTDL_INFO, "Unregistered netproc function\n");
+			syslog(LOG_INFO, "Unregistered netproc function\n");
 			p = cur->next;
 			if (cur == NetprocHookTable) {
 				NetprocHookTable = p;
@@ -539,7 +528,7 @@ void CtdlDestroyNetprocHooks(void)
 	cur = NetprocHookTable;
 	while (cur != NULL)
 	{
-		CtdlLogPrintf(CTDL_INFO, "Destroyed netproc function\n");
+		syslog(LOG_INFO, "Destroyed netproc function\n");
 		p = cur->next;
 		free(cur);
 		cur = p;
@@ -558,7 +547,7 @@ void CtdlRegisterDeleteHook(void (*handler)(char *, long) )
 	newfcn->h_function_pointer = handler;
 	DeleteHookTable = newfcn;
 
-	CtdlLogPrintf(CTDL_INFO, "Registered a new delete function\n");
+	syslog(LOG_INFO, "Registered a new delete function\n");
 }
 
 
@@ -570,7 +559,7 @@ void CtdlUnregisterDeleteHook(void (*handler)(char *, long) )
 		/* This will also remove duplicates if any */
 		while (cur != NULL &&
 				handler == cur->h_function_pointer ) {
-			CtdlLogPrintf(CTDL_INFO, "Unregistered delete function\n");
+			syslog(LOG_INFO, "Unregistered delete function\n");
 			p = cur->next;
 			if (cur == DeleteHookTable) {
 				DeleteHookTable = p;
@@ -587,7 +576,7 @@ void CtdlDestroyDeleteHooks(void)
 	cur = DeleteHookTable;
 	while (cur != NULL)
 	{
-		CtdlLogPrintf(CTDL_INFO, "Destroyed delete function\n");
+		syslog(LOG_INFO, "Destroyed delete function\n");
 		p = cur->next;
 		free(cur);
 		cur = p;		
@@ -609,7 +598,7 @@ void CtdlRegisterFixedOutputHook(char *content_type, void (*handler)(char *, int
 	safestrncpy(newfcn->content_type, content_type, sizeof newfcn->content_type);
 	FixedOutputTable = newfcn;
 
-	CtdlLogPrintf(CTDL_INFO, "Registered a new fixed output function for %s\n", newfcn->content_type);
+	syslog(LOG_INFO, "Registered a new fixed output function for %s\n", newfcn->content_type);
 }
 
 
@@ -620,7 +609,7 @@ void CtdlUnregisterFixedOutputHook(char *content_type)
 	for (cur = FixedOutputTable; cur != NULL; cur = cur->next) {
 		/* This will also remove duplicates if any */
 		while (cur != NULL && (!strcasecmp(content_type, cur->content_type))) {
-			CtdlLogPrintf(CTDL_INFO, "Unregistered fixed output function for %s\n", content_type);
+			syslog(LOG_INFO, "Unregistered fixed output function for %s\n", content_type);
 			p = cur->next;
 			if (cur == FixedOutputTable) {
 				FixedOutputTable = p;
@@ -638,7 +627,7 @@ void CtdlDestroyFixedOutputHooks(void)
 	cur = FixedOutputTable; 
 	while (cur != NULL)
 	{
-		CtdlLogPrintf(CTDL_INFO, "Destroyed fixed output function for %s\n", cur->content_type);
+		syslog(LOG_INFO, "Destroyed fixed output function for %s\n", cur->content_type);
 		p = cur->next;
 		free(cur);
 		cur = p;
@@ -675,7 +664,7 @@ void CtdlRegisterXmsgHook(int (*fcn_ptr) (char *, char *, char *, char *), int o
 	newfcn->order = order;
 	newfcn->h_function_pointer = fcn_ptr;
 	XmsgHookTable = newfcn;
-	CtdlLogPrintf(CTDL_INFO, "Registered a new x-msg function (priority %d)\n", order);
+	syslog(LOG_INFO, "Registered a new x-msg function (priority %d)\n", order);
 }
 
 
@@ -688,7 +677,7 @@ void CtdlUnregisterXmsgHook(int (*fcn_ptr) (char *, char *, char *, char *), int
 		while (cur != NULL &&
 				fcn_ptr == cur->h_function_pointer &&
 				order == cur->order) {
-			CtdlLogPrintf(CTDL_INFO, "Unregistered x-msg function "
+			syslog(LOG_INFO, "Unregistered x-msg function "
 					"(priority %d)\n", order);
 			p = cur->next;
 			if (cur == XmsgHookTable) {
@@ -707,7 +696,7 @@ void CtdlDestroyXmsgHooks(void)
 	cur = XmsgHookTable;
 	while (cur != NULL)
 	{
-		CtdlLogPrintf(CTDL_INFO, "Destroyed x-msg function "
+		syslog(LOG_INFO, "Destroyed x-msg function "
 			"(priority %d)\n", cur->order);
 		p = cur->next;
 			
@@ -727,12 +716,11 @@ void CtdlRegisterServiceHook(int tcp_port,
 {
 	struct ServiceFunctionHook *newfcn;
 	char *message;
-	char *error;
+	char error[SIZ];
 
-	error = NULL;
-	newfcn = (struct ServiceFunctionHook *)
-	    malloc(sizeof(struct ServiceFunctionHook));
-	message = (char*) malloc (SIZ);
+	strcpy(error, "");
+	newfcn = (struct ServiceFunctionHook *) malloc(sizeof(struct ServiceFunctionHook));
+	message = (char*) malloc (SIZ + SIZ);
 	
 	newfcn->next = ServiceHookTable;
 	newfcn->tcp_port = tcp_port;
@@ -743,20 +731,20 @@ void CtdlRegisterServiceHook(int tcp_port,
 	newfcn->ServiceName = ServiceName;
 
 	if (sockpath != NULL) {
-		newfcn->msock = ig_uds_server(sockpath, config.c_maxsessions, &error);
+		newfcn->msock = ctdl_uds_server(sockpath, config.c_maxsessions, error);
 		snprintf(message, SIZ, "Unix domain socket '%s': ", sockpath);
 	}
 	else if (tcp_port <= 0) {	/* port -1 to disable */
-		CtdlLogPrintf(CTDL_INFO, "Service %s has been manually disabled, skipping\n", ServiceName);
+		syslog(LOG_INFO, "Service %s has been manually disabled, skipping\n", ServiceName);
 		free (message);
 		free(newfcn);
 		return;
 	}
 	else {
-		newfcn->msock = ig_tcp_server(config.c_ip_addr,
+		newfcn->msock = ctdl_tcp_server(config.c_ip_addr,
 					      tcp_port,
 					      config.c_maxsessions, 
-					      &error);
+					      error);
 		snprintf(message, SIZ, "TCP port %s:%d: (%s) ", 
 			 config.c_ip_addr, tcp_port, ServiceName);
 	}
@@ -764,13 +752,12 @@ void CtdlRegisterServiceHook(int tcp_port,
 	if (newfcn->msock > 0) {
 		ServiceHookTable = newfcn;
 		strcat(message, "registered.");
-		CtdlLogPrintf(CTDL_INFO, "%s\n", message);
+		syslog(LOG_INFO, "%s\n", message);
 	}
 	else {
 		AddPortError(message, error);
 		strcat(message, "FAILED.");
-		CtdlLogPrintf(CTDL_CRIT, "%s\n", message);
-		free(error);
+		syslog(LOG_CRIT, "%s\n", message);
 		free(newfcn);
 	}
 	free(message);
@@ -785,7 +772,8 @@ void CtdlUnregisterServiceHook(int tcp_port, char *sockpath,
 {
 	struct ServiceFunctionHook *cur, *p;
 
-	for (cur = ServiceHookTable; cur != NULL; cur = cur->next) {
+	cur = ServiceHookTable;
+	while (cur != NULL) {
 		/* This will also remove duplicates if any */
 		while (cur != NULL &&
 				!(sockpath && cur->sockpath &&
@@ -796,12 +784,12 @@ void CtdlUnregisterServiceHook(int tcp_port, char *sockpath,
 				tcp_port == cur->tcp_port) {
 			close(cur->msock);
 			if (sockpath) {
-				CtdlLogPrintf(CTDL_INFO, "Closed UNIX domain socket %s\n",
+				syslog(LOG_INFO, "Closed UNIX domain socket %s\n",
 						sockpath);
 			} else if (tcp_port) {
-				CtdlLogPrintf(CTDL_INFO, "Closed TCP port %d\n", tcp_port);
+				syslog(LOG_INFO, "Closed TCP port %d\n", tcp_port);
 			} else {
-				CtdlLogPrintf(CTDL_INFO, "Unregistered service \"%s\"\n", cur->ServiceName);
+				syslog(LOG_INFO, "Unregistered service \"%s\"\n", cur->ServiceName);
 			}
 			p = cur->next;
 			if (cur == ServiceHookTable) {
@@ -813,6 +801,32 @@ void CtdlUnregisterServiceHook(int tcp_port, char *sockpath,
 	}
 }
 
+
+void CtdlShutdownServiceHooks(void)
+{
+	/* sort of a duplicate of close_masters() but called earlier */
+	struct ServiceFunctionHook *cur;
+
+	cur = ServiceHookTable;
+	while (cur != NULL) 
+	{
+		if (cur->msock != -1)
+		{
+			close(cur->msock);
+			cur->msock = -1;
+			if (cur->sockpath != NULL){
+				syslog(LOG_INFO, "[%s] Closed UNIX domain socket %s\n",
+					      cur->ServiceName,
+					      cur->sockpath);
+			} else {
+				syslog(LOG_INFO, "[%s] closing service\n", 
+					      cur->ServiceName);
+			}
+		}
+		cur = cur->next;
+	}
+}
+
 void CtdlDestroyServiceHook(void)
 {
 	struct ServiceFunctionHook *cur, *p;
@@ -822,12 +836,12 @@ void CtdlDestroyServiceHook(void)
 	{
 		close(cur->msock);
 		if (cur->sockpath) {
-			CtdlLogPrintf(CTDL_INFO, "Closed UNIX domain socket %s\n",
+			syslog(LOG_INFO, "Closed UNIX domain socket %s\n",
 				cur->sockpath);
 		} else if (cur->tcp_port) {
-			CtdlLogPrintf(CTDL_INFO, "Closed TCP port %d\n", cur->tcp_port);
+			syslog(LOG_INFO, "Closed TCP port %d\n", cur->tcp_port);
 		} else {
-			CtdlLogPrintf(CTDL_INFO, "Destroyed service \"%s\"\n", cur->ServiceName);
+			syslog(LOG_INFO, "Destroyed service \"%s\"\n", cur->ServiceName);
 		}
 		p = cur->next;
 		free(cur);
@@ -851,7 +865,7 @@ void CtdlRegisterSearchFuncHook(void (*fcn_ptr)(int *, long **, const char *), c
 	newfcn->fcn_ptr = fcn_ptr;
 	SearchFunctionHookTable = newfcn;
 
-	CtdlLogPrintf(CTDL_INFO, "Registered a new search function (%s)\n", name);
+	syslog(LOG_INFO, "Registered a new search function (%s)\n", name);
 }
 
 void CtdlUnregisterSearchFuncHook(void (*fcn_ptr)(int *, long **, const char *), char *name)
@@ -860,7 +874,7 @@ void CtdlUnregisterSearchFuncHook(void (*fcn_ptr)(int *, long **, const char *),
 	
 	for (cur = SearchFunctionHookTable; cur != NULL; cur = cur->next) {
 		while (fcn_ptr && (cur->fcn_ptr == fcn_ptr) && name && !strcmp(name, cur->name)) {
-			CtdlLogPrintf(CTDL_INFO, "Unregistered search function(%s)\n", name);
+			syslog(LOG_INFO, "Unregistered search function(%s)\n", name);
 			p = cur->next;
 			if (cur == SearchFunctionHookTable) {
 				SearchFunctionHookTable = p;
@@ -871,6 +885,19 @@ void CtdlUnregisterSearchFuncHook(void (*fcn_ptr)(int *, long **, const char *),
 	}
 }
 
+void CtdlDestroySearchHooks(void)
+{
+        struct SearchFunctionHook *cur, *p;
+
+	cur = SearchFunctionHookTable;
+	SearchFunctionHookTable = NULL;
+        while (cur != NULL) {
+		p = cur->next;
+		free(cur);
+		cur = p;
+	}
+}
+
 void CtdlModuleDoSearch(int *num_msgs, long **search_msgs, const char *search_string, const char *func_name)
 {
 	struct SearchFunctionHook *fcn = NULL;
@@ -892,7 +919,7 @@ void PerformSessionHooks(int EventType)
 	for (fcn = SessionHookTable; fcn != NULL; fcn = fcn->next) {
 		if (fcn->eventtype == EventType) {
 			if (EventType == EVT_TIMER) {
-				citthread_setspecific(MyConKey, NULL);	/* for every hook */
+				pthread_setspecific(MyConKey, NULL);	/* for every hook */
 			}
 			(*fcn->h_function_pointer) ();
 		}
@@ -917,11 +944,10 @@ int PerformMessageHooks(struct CtdlMessage *msg, int EventType)
 
 	/* Other code may elect to protect this message from server-side
 	 * handlers; if this is the case, don't do anything.
-	CtdlLogPrintf(CTDL_DEBUG, "** Event type is %d, flags are %d\n",
-		EventType, msg->cm_flags);
+	syslog(LOG_DEBUG, "** Event type is %d, flags are %d\n", EventType, msg->cm_flags);
 	 */
 	if (msg->cm_flags & CM_SKIP_HOOKS) {
-		CtdlLogPrintf(CTDL_DEBUG, "Skipping hooks\n");
+		syslog(LOG_DEBUG, "Skipping hooks\n");
 		return(0);
 	}
 
@@ -929,8 +955,7 @@ int PerformMessageHooks(struct CtdlMessage *msg, int EventType)
 	 */
 	for (fcn = MessageHookTable; fcn != NULL; fcn = fcn->next) {
 		if (fcn->eventtype == EventType) {
-			total_retval = total_retval +
-				(*fcn->h_function_pointer) (msg);
+			total_retval = total_retval + (*fcn->h_function_pointer) (msg);
 		}
 	}
 
@@ -947,7 +972,7 @@ int PerformRoomHooks(struct ctdlroom *target_room)
 	struct RoomFunctionHook *fcn;
 	int total_retval = 0;
 
-	CtdlLogPrintf(CTDL_DEBUG, "Performing room hooks for <%s>\n", target_room->QRname);
+	syslog(LOG_DEBUG, "Performing room hooks for <%s>\n", target_room->QRname);
 
 	for (fcn = RoomHookTable; fcn != NULL; fcn = fcn->next) {
 		total_retval = total_retval + (*fcn->fcn_ptr) (target_room);
