@@ -2,7 +2,7 @@
 #define __USER_OPS_H__
 
 #include <ctype.h>
-/* $Id$ */
+#include <syslog.h>
 int hash (char *str);
 /* getuser is deprecated, use CtdlGetUser instead */
 int getuser (struct ctdluser *, char *) __attribute__ ((deprecated));
@@ -20,8 +20,6 @@ void rebuild_usersbynumber(void);
 void cmd_user (char *cmdbuf);
 void session_startup (void);
 void logged_in_response(void);
-/* logout() is deprecated use CtdlUserLogout() instead */
-void logout (void) __attribute__ ((deprecated));
 int purge_user (char *pname);
 int create_user (const char *newusername, long len, int become_user);
 void do_login(void);
@@ -69,10 +67,10 @@ static INLINE long cutuserkey(char *username) {
 	len = strlen(username);
 	if (len >= USERNAME_SIZE)
 	{
-		CtdlLogPrintf (CTDL_EMERG, "Username to long: %s", username);
+		syslog(LOG_EMERG, "Username to long: %s", username);
 		cit_backtrace ();
 		len = USERNAME_SIZE - 1; 
-		((char*)username)[USERNAME_SIZE - 1]='\0';
+		username[len]='\0';
 	}
 	return len;
 }
@@ -87,7 +85,7 @@ static INLINE void makeuserkey(char *key, const char *username, long len) {
 
 	if (len >= USERNAME_SIZE)
 	{
-		CtdlLogPrintf (CTDL_EMERG, "Username to long: %s", username);
+		syslog(LOG_EMERG, "Username to long: %s", username);
 		cit_backtrace ();
 		len = USERNAME_SIZE - 1; 
 	}
